@@ -27,7 +27,7 @@ class Source;
 class TDEConfig;
 
 class FlowLayout : public TQLayout{
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 public:
 	/**
@@ -68,10 +68,6 @@ public:
 	TQSizePolicy::ExpandData expanding() const;
 	Qt::Orientation getOrientation() const;
 
-#ifdef USE_QT4
-	QLAYOUT_REQUIRED_METHOD_DECLARATIONS
-#endif // USE_QT4
-
 public slots:
 	void setOrientation(Qt::Orientation orientation);
 
