@@ -28,7 +28,7 @@
  * HDDTempSrc reads temperature of your harddisk provided by hddtemp
  */
 class HDDTempSrc : public LabelSource {
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 
 	/**
