@@ -30,7 +30,7 @@
  * which is provided by the i8k kernel module.
  */
 class I8kSrc : public LabelSource {
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 public:
 	/**
